@@ -319,17 +319,23 @@ count_row_column (Py_UNICODE *start, Py_UNICODE *pos, unsigned long *offset,
 	*offset = (pos - start);
 	*row = 1;
 	
-	/* Count newlines in chars <= pos */
-	for (ptr = start; ptr && ptr <= pos; ptr++)
+	/* Count newlines in chars < pos */
+	for (ptr = start; ptr < pos; ptr++)
 	{
 		if (*ptr == '\n') (*row)++;
 	}
-	ptr--;
 	
-	/* Loop backwards to find the column */
-	while (ptr > start && *ptr != '\n') ptr--;
-	*column = (pos - ptr);
-	if (*row == 1) (*column)++;
+	if (*row == 1)
+	{
+		*column = *offset + 1;
+	}
+	else
+	{
+		ptr--;
+		/* Loop backwards to find the column */
+		while (ptr > start && *ptr != '\n') ptr--;
+		*column = (pos - ptr);
+	}
 }
 
 static void
@@ -2570,7 +2576,7 @@ PyMODINIT_FUNC
 initjsonlib (void)
 {
 	PyObject *module;
-	PyObject *version;
+	PyObject *version, *read, *write;
 	
 	if (!(module = Py_InitModule3 ("jsonlib", module_methods,
 	                               module_doc)))
@@ -2595,10 +2601,19 @@ initjsonlib (void)
 	PyModule_AddObject(module, "UnknownSerializerError",
 	                   UnknownSerializerError);
 	
+	/* Aliases */
+	read = PyObject_GetAttrString (module, "read");
+	write = PyObject_GetAttrString (module, "write");
+	if (!(read && write))
+		return;
+	
+	PyModule_AddObject (module, "loads", read);
+	PyModule_AddObject (module, "dumps", write);
+	
 	/* If you change the version here, also change it in setup.py and
 	 * jsonlib.py.
 	**/
-	version = Py_BuildValue ("(iii)", 1, 3, 6);
+	version = Py_BuildValue ("(iii)", 1, 3, 7);
 	PyModule_AddObject (module, "__version__", version);
 }
 /* }}} */
